@@ -17,25 +17,14 @@
 #ifndef MYSQL_KEYRING_SECURE_STRING
 #define MYSQL_KEYRING_SECURE_STRING
 
-#include <sstream>
 #include "keyring_memory.h"
+#include <sstream>
 
-#include <boost/optional/optional_fwd.hpp>
+namespace keyring
+{
+  typedef std::basic_string<char, std::char_traits<char>, Secure_allocator<char> > Secure_string;
+  typedef std::basic_ostringstream<char, std::char_traits<char>, Secure_allocator<char> > Secure_ostringstream;
+  typedef std::basic_istringstream<char, std::char_traits<char>, Secure_allocator<char> > Secure_istringstream;
+}
 
-namespace keyring {
-typedef std::basic_string<char, std::char_traits<char>, Secure_allocator<char>>
-    Secure_string;
-typedef std::basic_ostringstream<char, std::char_traits<char>,
-                                 Secure_allocator<char>>
-    Secure_ostringstream;
-typedef std::basic_istringstream<char, std::char_traits<char>,
-                                 Secure_allocator<char>>
-    Secure_istringstream;
-typedef std::basic_stringstream<char, std::char_traits<char>,
-                                Secure_allocator<char>>
-    Secure_stringstream;
-
-typedef boost::optional<Secure_string> Optional_secure_string;
-}  // namespace keyring
-
-#endif  // MYSQL_KEYRING_SECURE_STRING
+#endif // MYSQL_KEYRING_SECURE_STRING
