@@ -1574,9 +1574,9 @@ backup_finish()
 	/* release all locks */
 	if (!opt_no_lock) {
 		unlock_all(mysql_connection);
-		history_lock_time = 0;
-	} else {
 		history_lock_time = time(NULL) - history_lock_time;
+	} else {
+		history_lock_time = 0;
 	}
 
 	if (opt_safe_slave_backup && sql_thread_started) {
@@ -2026,8 +2026,7 @@ copy_back(int argc, char **argv)
 					   &master_key,
 					   &version);
 
-		msg_ts("Generated new master key with ID '%s-%lu'.\n",
-		       server_uuid, master_key_id);
+		msg_ts("Generated new master key");
 
 	        my_free(master_key);
 
