@@ -84,13 +84,13 @@ bool
 write_backup_config_file();
 
 bool
-lock_binlog_maybe(MYSQL *connection);
+lock_binlog_maybe(MYSQL *connection, int timeout, int retry_count);
 
 bool
-lock_tables_for_backup(MYSQL *connection, int timeout = 31536000);
+lock_tables_for_backup(MYSQL *connection, int timeout, int retry_count);
 
 bool
-lock_tables_maybe(MYSQL *connection);
+lock_tables_maybe(MYSQL *connection, int timeout, int retry_count);
 
 bool
 wait_for_safe_slave(MYSQL *connection);
