@@ -1,5 +1,5 @@
 /******************************************************
-Copyright (c) 2011-2013 Percona LLC and/or its affiliates.
+Copyright (c) 2011-2020 Percona LLC and/or its affiliates.
 
 The xbstream utility: serialize/deserialize files in the XBSTREAM format.
 
@@ -63,7 +63,7 @@ static my_bool		opt_verbose = 0;
 static int		opt_parallel = 1;
 static ulong 		opt_encrypt_algo;
 static char 		*opt_encrypt_key_file = NULL;
-static void 		*opt_encrypt_key = NULL;
+static char 		*opt_encrypt_key = NULL;
 static int		opt_encrypt_threads = 1;
 
 enum {
@@ -90,8 +90,7 @@ static struct my_option my_long_options[] =
 	{"decrypt", 'd', "Decrypt files ending with .xbcrypt.",
 	 &opt_encrypt_algo, &opt_encrypt_algo, &xbstream_encrypt_algo_typelib,
 	 GET_ENUM, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-	{"encrypt-key", 'k', "Encryption key.",
-	 &opt_encrypt_key, &opt_encrypt_key, 0,
+	{"encrypt-key", 'k', "Encryption key", 0, 0, 0,
 	 GET_STR_ALLOC, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
 	{"encrypt-key-file", 'f', "File which contains encryption key.",
 	 &opt_encrypt_key_file, &opt_encrypt_key_file, 0,
@@ -244,6 +243,9 @@ get_one_option(int optid, const struct my_option *opt __attribute__((unused)),
 			return TRUE;
 		}
 		break;
+	case 'k':
+		hide_option(argument, &opt_encrypt_key);
+		break;
 	case '?':
 		usage();
 		exit(0);
