@@ -4,14 +4,19 @@
 
 . inc/common.sh
 
-if [ -z ${KEYRING_TYPE+x} ]; then
-  KEYRING_TYPE="component"
-fi
+plugin_load=keyring_vault.so
+plugin_dir=${XTRABACKUP_BASEDIR}/keyring_vault
+keyring_vault_config=${TEST_VAR_ROOT}/keyring_vault_config
+keyring_args="--keyring-vault-config=${keyring_vault_config}"
 
-instance_local_manifest=""
-keyring_component_cnf=${TEST_VAR_ROOT}/component_keyring_vault.cnf
-keyring_args="--component-keyring-config=${keyring_component_cnf}"
+MYSQLD_EXTRA_MY_CNF_OPTS="${MYSQLD_EXTRA_MY_CNF_OPTS:-""}
+early-plugin-load=${plugin_load}
+keyring-vault-config=${keyring_vault_config}
+"
 
+XB_EXTRA_MY_CNF_OPTS="${XB_EXTRA_MY_CNF_OPTS:-""}
+xtrabackup-plugin-dir=${plugin_dir}
+"
 
 VAULT_URL="${VAULT_URL:-https://vault.public-ci.percona.com:8200}"
 VAULT_MOUNT_POINT=$(uuidgen)
@@ -22,48 +27,22 @@ function keyring_vault_ping()
 {
 	curl -H "X-Vault-Token: ${VAULT_TOKEN}" \
 		--cacert "${VAULT_CA}" -k \
-		--connect-timeout 3 \
 		"${VAULT_URL}/v1/sys/mounts" || \
 	return 1
 }
 
-function configure_keyring_file_component()
+function keyring_vault_mount()
 {
-	local VAULT_MOUNT_DATA=""
-  if [ "$MYSQL_DEBUG_MODE" = "on" ]; then
-    binary="mysqld-debug"
-  else
-    binary="mysqld"
-  fi
-  instance_local_manifest="${TEST_VAR_ROOT}/${binary}.my"
-  cat <<EOF > "${MYSQLD_DATADIR}/${binary}.my"
-{
-    "components": "file://component_keyring_vault"
-}
+	cat > ${keyring_vault_config} <<EOF
+vault_url = ${VAULT_URL}
+secret_mount_point = ${VAULT_MOUNT_POINT}
+token = ${VAULT_TOKEN}
+vault_ca = ${VAULT_CA}
 EOF
-  cat <<EOF > "${MYSQLD_DATADIR}/component_keyring_vault.cnf"
-{
-  "vault_url": "${VAULT_URL}",
-  "secret_mount_point": "${VAULT_MOUNT_POINT}",
-  "secret_mount_point_version": "${VAULT_CONFIG_VERSION}",
-  "token": "${VAULT_TOKEN}",
-  "vault_ca": "${VAULT_CA}"
-}
-EOF
-  cp "${MYSQLD_DATADIR}/${binary}.my" ${instance_local_manifest}
-  cp "${MYSQLD_DATADIR}/component_keyring_vault.cnf" ${keyring_component_cnf}
-
-	if [[ "${VAULT_MOUNT_VERSION}" -eq "1" ]];
-	then
-		VAULT_MOUNT_DATA="{\"type\":\"kv\"}"
-	elif [[ "${VAULT_MOUNT_VERSION}" -eq "2" ]];
-	then
-		VAULT_MOUNT_DATA="{\"type\":\"kv\", \"options\": { \"version\":\"2\" }}"
-	fi
 
 	curl -H "X-Vault-Token: ${VAULT_TOKEN}" \
 		--cacert "${VAULT_CA}" -k \
-		--data "${VAULT_MOUNT_DATA}" \
+		--data '{"type":"generic"}' \
 		-X POST \
 		"${VAULT_URL}/v1/sys/mounts/${VAULT_MOUNT_POINT}"
 	return $?
