@@ -211,7 +211,7 @@ rm -rf $backup_dir/*
 
 vlog "Testing with --tables-exclude=..."
 xtrabackup --backup \
-	--tables-exclude='ancor,glow,test,thisisa.*,ignore,mysql.*' \
+	--tables-exclude='ancor,glow,test,thisisa.*,ignore,mysql.*,sys.*' \
 	--target-dir=$backup_dir --datadir=$mysql_datadir
 expect_dir_contents $backup_dir <<EOF
 ./database1/t1.ibd
@@ -226,7 +226,7 @@ rm -rf $backup_dir/*
 vlog "Testing with both --tables and --tables-exclude=..."
 xtrabackup --backup \
 	--tables='ancor,glow,test,thisisa.*,ignore,t.*,mysql.*' \
-	--tables-exclude='ancor,glow,test,thisisa.*,ignore,mysql.*' \
+	--tables-exclude='ancor,glow,test,thisisa.*,ignore,mysql.*,sys.*' \
 	--target-dir=$backup_dir --datadir=$mysql_datadir
 expect_dir_contents $backup_dir <<EOF
 ./database1/t1.ibd
