@@ -1,21 +1,14 @@
 /*
-   Copyright (c) 2003, 2023, Oracle and/or its affiliates.
+   Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License, version 2.0,
-   as published by the Free Software Foundation.
-
-   This program is also distributed with certain software (including
-   but not limited to OpenSSL) that is licensed under separate terms,
-   as designated in a particular file or component or in included license
-   documentation.  The authors of MySQL hereby grant you an additional
-   permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License, version 2.0, for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -34,21 +27,22 @@ class NdbResultSet;
  * @class NdbIndexOperation
  * @brief Class of index operations for use in transactions
  */
-class NdbIndexOperation : public NdbOperation {
+class NdbIndexOperation : public NdbOperation
+{
 #ifndef DOXYGEN_SHOULD_SKIP_INTERNAL
   friend class Ndb;
   friend class NdbImpl;
   friend class NdbTransaction;
 #endif
 
- public:
+public:
   /**
    * @name Define Standard Operation
    * @{
    */
 
   /** insert is not allowed */
-  int insertTuple() override;
+  int insertTuple();
 
   /**
    * Define the NdbIndexOperation to be a standard operation of type readTuple.
@@ -57,7 +51,7 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int readTuple(LockMode) override;
+  int readTuple(LockMode);
 
 #ifndef DOXYGEN_SHOULD_SKIP_DEPRECATED
   /**
@@ -67,7 +61,7 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int readTuple() override;
+  int readTuple();
 
   /**
    * Define the NdbIndexOperation to be a standard operation of type
@@ -77,7 +71,7 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int readTupleExclusive() override;
+  int readTupleExclusive();
 
   /**
    * Define the NdbIndexOperation to be a standard operation of type simpleRead.
@@ -96,27 +90,27 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int simpleRead() override;
+  int simpleRead();
 
   /**
    * Define the NdbOperation to be a standard operation of type committedRead.
-   * When calling NdbTransaction::execute, this operation
+   * When calling NdbTransaction::execute, this operation 
    * read latest committed value of the record.
    *
-   * This means that if another transaction is updating the
-   * record, then the current transaction will not wait.
-   * It will instead use the latest committed value of the
+   * This means that if another transaction is updating the 
+   * record, then the current transaction will not wait.  
+   * It will instead use the latest committed value of the 
    * record.
    *
    * @return 0 if successful otherwise -1.
    */
-  int dirtyRead() override;
+  int dirtyRead();
 
-  int committedRead() override;
+  int committedRead();
 #endif
 
   /**
-   * Define the NdbIndexOperation to be a standard operation of type
+   * Define the NdbIndexOperation to be a standard operation of type 
    * updateTuple.
    *
    * When calling NdbTransaction::execute, this operation
@@ -124,10 +118,10 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int updateTuple() override;
+  int updateTuple();
 
   /**
-   * Define the NdbIndexOperation to be a standard operation of type
+   * Define the NdbIndexOperation to be a standard operation of type 
    * deleteTuple.
    *
    * When calling NdbTransaction::execute, this operation
@@ -135,16 +129,16 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int deleteTuple() override;
+  int deleteTuple();
 
   /**
    * Get index object for this operation
    */
-  const NdbDictionary::Index *getIndex() const;
+  const NdbDictionary::Index * getIndex() const;
 
 #ifndef DOXYGEN_SHOULD_SKIP_DEPRECATED
   /**
-   * Define the NdbIndexOperation to be a standard operation of type
+   * Define the NdbIndexOperation to be a standard operation of type 
    * dirtyUpdate.
    *
    * When calling NdbTransaction::execute, this operation
@@ -152,52 +146,46 @@ class NdbIndexOperation : public NdbOperation {
    *
    * @return 0 if successful otherwise -1.
    */
-  int dirtyUpdate() override;
+  int dirtyUpdate();
 #endif
 
 #ifndef DOXYGEN_SHOULD_SKIP_INTERNAL
   /** @} *********************************************************************/
   /**
-   * @name Define Interpreted Program Operation
+   * @name Define Interpreted Program Operation 
    * @{
    */
 
-  /**
-   * Write a tuple using an interpreted program(Currently, not supported).
-   *
-   * @return 0 if successful otherwise -1.
-   */
-  int interpretedWriteTuple() override;
-
   /**
    * Update a tuple using an interpreted program.
    *
    * @return 0 if successful otherwise -1.
    */
-  int interpretedUpdateTuple() override;
+  int interpretedUpdateTuple();
 
   /**
    * Delete a tuple using an interpreted program.
    *
    * @return 0 if successful otherwise -1.
    */
-  int interpretedDeleteTuple() override;
+  int interpretedDeleteTuple();
 #endif
-
+  
   /** @} *********************************************************************/
 
- private:
-  NdbIndexOperation(Ndb *aNdb);
-  ~NdbIndexOperation() override;
+private:
+  NdbIndexOperation(Ndb* aNdb);
+  ~NdbIndexOperation();
 
-  int receiveTCINDXREF(const NdbApiSignal *aSignal);
+  int receiveTCINDXREF(const NdbApiSignal* aSignal);
 
   // Overloaded methods from NdbCursorOperation
-  int indxInit(const class NdbIndexImpl *anIndex,
-               const class NdbTableImpl *aTable, NdbTransaction *);
+  int indxInit(const class NdbIndexImpl* anIndex,
+	       const class NdbTableImpl* aTable, 
+	       NdbTransaction*);
 
   // Private attributes
-  const NdbIndexImpl *m_theIndex;
+  const NdbIndexImpl* m_theIndex;
   friend struct Ndb_free_list_t<NdbIndexOperation>;
 };
 
